function [d1, d2] = DetectorPairFromLOR(i, j, alpha, sz, R, N_det, act_phantom)
% =========================================================================
% Funkce DetectorPairFromLOR ur? pr?se?ky p?mky vedouc bodem (i, j) pod
% hlem alpha s krunic o polom?ru R.
%
% Parametry:
%   i      - index (osa x)
%   j      - index (osa y)
%   alpha  - uhel generovane primky s vektorem (1, 0)
%   sz     - velikost snimane oblasti (ctvercova), stred je na souradnicich
%            (0, 0)
%   R      - polomer kruznice se stredem (0, 0)
%   N_det  - pocet detektorovych jednotek rozmistenych na kruznici R
%            indexovani detektor? je podle hodinovch ru?i?ek, detektor s
%            indexem 1 je na 12h, tj. na pozici (0, R)
% =========================================================================

    % xi, yj - souradnice pixelu
    xi = i + (sz / 2 - 2 * floor(sz / 2));
    xj = -(j + (sz / 2 - 2 * floor(sz / 2)));
    
    % primka, obecna rovnice Ax + By + C = 0
    ca = cos(alpha); sa=sin(alpha);
    C =  sa .* xi - ca .* xj;
    % vzdalenost od pocatku (kolma) je abs(C) / sqrt(A^2 + B^2)
    % a prumet pocatku na primku --> (x0, y0)
    dist_0 = abs(C);
    x0 =  C .* sa; y0 = -C .* ca;
    
    if exist('act_phantom', 'var')
        N_plot = 100;
        stred = sz / 2;
        figure; imagesc(-stred+1:stred-1,-stred+1:stred-1,-act_phantom); colormap gray; hold on;
        plot(-R:R,-sqrt(R^2-(-R:R).^2),'g', 'LineWidth', 2);
        plot(-R:R, sqrt(R^2-(-R:R).^2),'g');
        for pj = 1:floor(numel(xi)/N_plot):numel(xi)
            plot([-R,R],-(- sa(pj)*[-R,R] - C(pj))/ca(pj),'r');
        end
        axis([-R,R,-R,R]);
    end
    
    % vzdalenost pruseciku s kruznici od prumetu
    D = sqrt(R.^2 - dist_0.^2);
    
    % Dopocteni pruseciku  - ve smeru (-B, A) ve vzdalenosti D od {x0, y0)
    y1 = y0 + D .* sa; y2 = y0 - D .* sa; 
    x1 = x0 + D .* ca; x2 = x0 - D .* ca; 
    
    % Uhel od primky ve smeru (0, 1)
    theta1 = acos(abs(y1)/R);
    theta2 = acos(abs(y2)/R);
    
    % Dopocitej uhel a index detektoru ( detektor s idx 1 je vlevo, tj. na pozici
    % (-sz/2, 0))
    d1 = 1 + floor(assign_quadrants(x1, y1, theta1) * N_det / (2*pi));
    d2 = 1 + floor(assign_quadrants(x2, y2, theta2) * N_det / (2*pi));
    
return;

function q=assign_quadrants(x, y, theta)

    q = zeros(size(theta));
    
    for i=1:numel(q)
        
        if x(i) > 0 && y(i) > 0
            q(i) = theta(i);  % pi/2 + theta
        end
        
        if x(i) <= 0 && y(i) > 0
            q(i) = 2 * pi - theta(i);
        end
        
        if x(i) > 0 && y(i) <= 0
            q(i) = pi - theta(i);
        end
        
        if x(i) <= 0 && y(i) <= 0
            q(i) = pi + theta(i);
        end
    end
return